-- Novell iSCSI ASN1 Schema Definitions
--
-- Novell Inc.
-- 1800 South Novell Place
-- Provo, UT 84606-6194

-- VeRsIoN=1.00
-- CoPyRiGhT=(c) Copyright 2002, Novell, Inc.  All rights reserved

-- Object ID Syntax
------------------------------------------
------------------------------------------
-- Change History:
--
-- Wed, April 10, 2002:  Initial revision (rawipfel)
-- Fri, Nov 22, 2002: iscsi prefix 334 assigned (rawipfel)
-- Thu, Jan 23, 2003: Novell schema review (rawipfel)
--
-- Naming Convention:
--  iscsi prefix to all iSCSI attributes and classes
--
------------------------------------------
------------------------------------------
--
-- ASN1 Object ID's Defined as Follows:
--     joint-iso-ccitt(2) country(16) us(840) organization(1)
--     Novell(113719) applications(1) iscsi(334)
--
--   components:
--     iscsiAttributeType(4)
--     iscsiClass(6)
--
------------------------------------------
-- 
-- Attribute range 1-100 is reserved for this file.
-- Class range 1-10 is reserved for this file.
-- 
------------------------------------------


iscsiSchemaExtensions DEFINITIONS ::=
BEGIN

-- New Attributes
------------------------------------------
------------------------------------------


"iscsiName" ATTRIBUTE ::=
{
  SyntaxID    SYN_CI_STRING,
  Flags       {DS_SINGLE_VALUED_ATTR, DS_SYNC_IMMEDIATE},
  ASN1ObjID   {2 16 840 1 113719 1 334 4 1}
}


"iscsiGUID" ATTRIBUTE ::=
{
  SyntaxID    SYN_OCTET_STRING,
  Flags       {DS_SYNC_IMMEDIATE},
  ASN1ObjID   {2 16 840 1 113719 1 334 4 2}
}


"iscsiNetAddress" ATTRIBUTE ::=
{
  SyntaxID    SYN_NET_ADDRESS,
  Flags       {DS_SYNC_IMMEDIATE},
  ASN1ObjID   {2 16 840 1 113719 1 334 4 3}
}


"iscsiTargetDN" ATTRIBUTE ::=
{
  SyntaxID    SYN_DIST_NAME,
  Flags       {DS_SYNC_IMMEDIATE},
  ASN1ObjID   {2 16 840 1 113719 1 334 4 10}
}


"iscsiServiceDN" ATTRIBUTE ::=
{
  SyntaxID    SYN_DIST_NAME,
  Flags       {DS_SYNC_IMMEDIATE},
  ASN1ObjID   {2 16 840 1 113719 1 334 4 11}
}


-- Class Modification (generic iscsi)
------------------------------------------
------------------------------------------
-- (none)

-- New Classes (generic iscsi)
------------------------------------------
------------------------------------------


"iscsiTarget" OBJECT-CLASS ::=
{
    Operation	ADD,
    Flags       {DS_EFFECTIVE_CLASS},
    SubClassOf	{"TOP"},
    MustContain {"CN"},
    MayContain  {
                    "iscsiName",
                    "iscsiGUID",
                    "iscsiServiceDN"
                },
    NamedBy	{"CN"},
    ContainedBy {"Locality", "Country", "domain", "Organization", "Organizational Unit", "NCS:NetWare Cluster"},
    ASN1ObjID   {2 16 840 1 113719 1 334 6 1}
}


"iscsiInitiator" OBJECT-CLASS ::=
{
    Operation	ADD,
    Flags       {DS_EFFECTIVE_CLASS},
    SubClassOf	{"TOP"},
    MustContain {"CN"},
    MayContain  {
                    "iscsiName",
                    "iscsiTargetDN",
                    "iscsiNetAddress"
                },
    NamedBy	{"CN"},
    ContainedBy {"Locality", "Country", "domain", "Organization", "Organizational Unit", "NCS:NetWare Cluster"},
    ASN1ObjID   {2 16 840 1 113719 1 334 6 2}
}


"iscsiServiceAux" OBJECT-CLASS ::=
{
    Operation   ADD,
    Flags       {DS_AUXILIARY_CLASS},
    MayContain  {
                    "iscsiTargetDN",
                    "iscsiNetAddress"
                },
    ASN1ObjID   {2 16 840 1 113719 1 334 6 10}
}


"iscsiInitiatorAux" OBJECT-CLASS ::=
{
    Operation   ADD,
    Flags       {DS_AUXILIARY_CLASS},
    MayContain  {
                    "iscsiName",
                    "iscsiTargetDN",
                    "iscsiNetAddress"
                },
    ASN1ObjID   {2 16 840 1 113719 1 334 6 11}
}


END
